import colorama
print(colorama.Fore.BLUE+'Pygl version - (17.4)'+colorama.Fore.RESET)
print(colorama.Fore.CYAN+colorama.Style.BRIGHT+'My Github --- ( https://github.com/dedisvoin/GRPgraph-versions )'+colorama.Fore.RESET,colorama.Style.RESET_ALL)
__version__ = '17.3'


from pygl_nf import GL

sound1 = GL.Sound_mixer_('Jump2.wav')

mouse = GL.Sub_events_.Mouse_init()
win = GL.Display_init_(flags=GL.D_Full)



def App():
    while win.CLOSE():
        win.UPDATE()


        win.GL.Rect('red',[300,500],[300,50],0,'s','D')

        if mouse.GET_PRESS_ON_PYGL_WINDOW():
            if win.GET_COLOR(mouse.GET_POSITION()[0],mouse.GET_POSITION()[1])==[255,0,0]:
                sound1.Play()

if __name__=='__main__':
    App()






from pygl_nf import GL


win = GL.Display_init_(flags=GL.D_Resize)

rect = win.GL.Rect(GL.c_NAVY,[200,200],[300,175],0,'s')
circle = win.GL.Circle(GL.c_CRIMSON,[500,500],93,0,'s')
ellips = win.GL.Ellips(GL.c_SKY_BLUE,[700,100],[300,112],0,'s')
triangl = win.GL.Triangl('red',[100,100],[200,100],[150,200],0,'s')
lines = win.GL.Line('green',[100,700],[700,600],6,'s','R')



draw_shapes = win.FUNCTION('draw',
    [
        rect.FILL,
        circle.FILL,
        ellips.FILL,
        triangl.FILL, 
        lines.OUTLINE
    ]
)

print('Shapes Count =',win.GET_SHAPES_COUNT())

def App():
    while win.CLOSE():
        win.UPDATE()
        
        draw_shapes.LOOP()
        
        

if __name__ == '__main__':
    App()


#from pygl_nf import GL
import time
import GL

GL.Widgets_().Get_Print_Widgets()

win = GL.Display_init_(
    flags=GL.D_Full
)

startTime = time.time()



text_box = GL.Widgets_.TextBoxs(
    win.screen,
    [10,10],[600,60],
    50,
    (200,200,200),
    (100,100,100),
    GL.Passing,
    10
)

button = GL.Widgets_.Buttons(
    win.screen,
    [10,80],[300,80],
    'Click',(20,180,60),
    60,60,
    (100,50,200),(60,60,170),(120,60,160),
    10,GL.Passing,
    10,(100,100,100)
)

drop_down = GL.Widgets_.DropDowns(
    win.screen,
    [650,10],[180,60],
    'Colors',
    [
        'red',
        'green',
        'blue',
        'yellow',
        'pink',
        'black',
        'white'
    ],
    10,
    (10,120,60),
    [
        'red',
        'green',
        'blue',
        'yellow',
        'pink',
        'black',
        'white'
    ],
    'down',
    False,(100,190,30),
    None,
    40
)

toggle = GL.Widgets_.Toggles(
    win.screen,
    [20,190],[60,30],
    'True'
)

slider = GL.Widgets_.Sliders(
    win.screen,
    [20,250],
    200,27,
    0,200,
    1,(100,200,160),(60,220,180)
)

GL.Progress_bar_time = 20
progressbar = GL.Widgets_.ProgressBar(
    win.screen,
    [100,700],[300,50],GL.Progres_bar_buffer,Curved=True)


def App():
    while win.CLOSE():
        win.UPDATE().SET_BG_COLOR()

        text_box.Update()
        button.Update()
        drop_down.Update()
        toggle.Update()
        slider.Update()
        progressbar.Update()
        text_box.Set_text(str(progressbar.Get_prcent()))

if __name__ == '__main__':
    App()
    

